==> chromium_76.0.3809.87.orig.tar.xz: chromium-76.0.3809.87/chrome/chrome_cleaner/engines/broker/engine_file_requests_impl.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_CHROME_CLEANER_ENGINES_BROKER_ENGINE_FILE_REQUESTS_IMPL_H_
#define CHROME_CHROME_CLEANER_ENGINES_BROKER_ENGINE_FILE_REQUESTS_IMPL_H_

#include "chrome/chrome_cleaner/engines/broker/interface_metadata_observer.h"
#include "chrome/chrome_cleaner/interfaces/engine_file_requests.mojom.h"
#include "chrome/chrome_cleaner/ipc/mojo_task_runner.h"
#include "mojo/public/cpp/bindings/associated_binding.h"

namespace chrome_cleaner {

class EngineFileRequestsImpl : public mojom::EngineFileRequests {
 public:
  EngineFileRequestsImpl(
      scoped_refptr<MojoTaskRunner> mojo_task_runner,
      InterfaceMetadataObserver* metadata_observer = nullptr);
  ~EngineFileRequestsImpl() override;

  void Bind(mojom::EngineFileRequestsAssociatedPtrInfo* ptr_info);

  // mojom::EngineFileRequests
  void SandboxFindFirstFile(
      const base::FilePath& file_name,
      SandboxFindFirstFileCallback result_callback) override;
  void SandboxFindNextFile(
      mojom::FindHandlePtr handle_ptr,
      SandboxFindNextFileCallback result_callback) override;
  void SandboxFindClose(mojom::FindHandlePtr handle_ptr,
                        SandboxFindCloseCallback result_callback) override;
  void SandboxOpenReadOnlyFile(
      const base::FilePath& file_name,
      uint32_t dwFlagsAndAttributes,
      SandboxOpenReadOnlyFileCallback result_callback) override;

 private:
  void FindFirstFile(const base::FilePath& file_name,
                     SandboxFindFirstFileCallback result_callback);
  void FindNextFile(mojom::FindHandlePtr handle_ptr,
                    SandboxFindNextFileCallback result_callback);
  void FindClose(mojom::FindHandlePtr handle_ptr,
                 SandboxFindCloseCallback result_callback);
  void OpenReadOnlyFile(const base::FilePath& file_name,
                        uint32_t dwFlagsAndAttributes,
                        SandboxOpenReadOnlyFileCallback result_callback);

  scoped_refptr<MojoTaskRunner> mojo_task_runner_;
  InterfaceMetadataObserver* metadata_observer_ = nullptr;
  mojo::AssociatedBinding<mojom::EngineFileRequests> binding_;
};

}  // namespace chrome_cleaner

#endif  // CHROME_CHROME_CLEANER_ENGINES_BROKER_ENGINE_FILE_REQUESTS_IMPL_H_

==> chromium_78.0.3904.97.orig.tar.xz: chromium-78.0.3904.97/chrome/chrome_cleaner/engines/broker/engine_file_requests_impl.h <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_CHROME_CLEANER_ENGINES_BROKER_ENGINE_FILE_REQUESTS_IMPL_H_
#define CHROME_CHROME_CLEANER_ENGINES_BROKER_ENGINE_FILE_REQUESTS_IMPL_H_

#include "chrome/chrome_cleaner/engines/broker/interface_metadata_observer.h"
#include "chrome/chrome_cleaner/mojom/engine_file_requests.mojom.h"
#include "chrome/chrome_cleaner/ipc/mojo_task_runner.h"
#include "mojo/public/cpp/bindings/associated_binding.h"

namespace chrome_cleaner {

class EngineFileRequestsImpl : public mojom::EngineFileRequests {
 public:
  EngineFileRequestsImpl(
      scoped_refptr<MojoTaskRunner> mojo_task_runner,
      InterfaceMetadataObserver* metadata_observer = nullptr);
  ~EngineFileRequestsImpl() override;

  void Bind(mojom::EngineFileRequestsAssociatedPtrInfo* ptr_info);

  // mojom::EngineFileRequests
  void SandboxFindFirstFile(
      const base::FilePath& file_name,
      SandboxFindFirstFileCallback result_callback) override;
  void SandboxFindNextFile(
      mojom::FindHandlePtr handle_ptr,
      SandboxFindNextFileCallback result_callback) override;
  void SandboxFindClose(mojom::FindHandlePtr handle_ptr,
                        SandboxFindCloseCallback result_callback) override;
  void SandboxOpenReadOnlyFile(
      const base::FilePath& file_name,
      uint32_t dwFlagsAndAttributes,
      SandboxOpenReadOnlyFileCallback result_callback) override;

 private:
  void FindFirstFile(const base::FilePath& file_name,
                     SandboxFindFirstFileCallback result_callback);
  void FindNextFile(mojom::FindHandlePtr handle_ptr,
                    SandboxFindNextFileCallback result_callback);
  void FindClose(mojom::FindHandlePtr handle_ptr,
                 SandboxFindCloseCallback result_callback);
  void OpenReadOnlyFile(const base::FilePath& file_name,
                        uint32_t dwFlagsAndAttributes,
                        SandboxOpenReadOnlyFileCallback result_callback);

  scoped_refptr<MojoTaskRunner> mojo_task_runner_;
  InterfaceMetadataObserver* metadata_observer_ = nullptr;
  mojo::AssociatedBinding<mojom::EngineFileRequests> binding_;
};

}  // namespace chrome_cleaner

#endif  // CHROME_CHROME_CLEANER_ENGINES_BROKER_ENGINE_FILE_REQUESTS_IMPL_H_
